@@ -36,7 +36,7 @@
 #define SPANK_NEWFPS	0x20
 #define SPANK_DOUBLEFPS 0x40
 
-static char gp_title[] = "dvdspanky 0.9 - (C) 2007 Jeffrey Grembecki\n\n";
+static char gp_title[] = "dvdspanky 0.9.1 - (C) 2007 Jeffrey Grembecki\n\n";
 static char gp_licence[] =
 "This program is free software; you can redistribute it and/or modify\n"
 "it under the terms of the GNU General Public License as published by\n"
@@ -54,7 +54,7 @@ static char gp_licence[] =
 "MA 02110-1301, USA.\n";
 
 static char gp_help[] =
-"%s -i file -o file [-bBpnNm12FIlhv] [-s size] [-r rate] [-R rate] [-c channels] [-V pixels] [-H pixels] [-a mode] [-f filters]\n"
+"%s -i file -o file [-bBpnNm12FILhv] [-s size] [-r rate] [-R rate] [-c channels] [-V pixels] [-H pixels] [-a mode] [-f filters]\n"
 "\n"
 "Following; [ ] = default, { } = requirements, * = experimental\n"
 "\n"
@@ -79,7 +79,7 @@ static char gp_help[] =
 "-f, --filters=FILTERS  eg. -f pp=de,hqdn3d [off]\n"
 "-I, --nonice           do not run at nice priority 19 [off]\n"
 "-v, --verbose          be verbose [off]\n"
-"-l, --licence          show the program licence\n"
+"-L, --licence          show the program licence\n"
 "-h, --help             this help text\n"
 "\nSee man 1 dvdspanky for more information\n";
 
@@ -105,11 +105,11 @@ static struct option gp_longopts[] =
 	{"frameadjust", 0, 0, 'F'},
 	{"filters", 1, 0, 'f'},
 	{"nonice", 0, 0, 'I'},
-	{"licence", 0, 0, 'l'},
+	{"licence", 0, 0, 'L'},
 	{"help", 0, 0, 'h'},
 	{"verbose", 0, 0, 'v'},
 };
-static char gp_shortopts[] = "vi:o:r:R:s:c:V:H:bBpnNa:mf:IlhF12";
+static char gp_shortopts[] = "vi:o:r:R:s:c:V:H:bBpnNa:mf:ILhF12";
 
 static int gp_inpipe[2];
 
@@ -144,79 +144,6 @@ void clearregex()
 	/* gp_mplexregex = NULL; gp_mplexstudy = NULL; */
 }
 
-int parsemplayer(const char *p_string)
-{
-	const char *p_error;
-	const char *p_id;
-	const char *p_value;
-	int p_vector[20];
-	int erroffset;
-	int numstrings;
-
-	if(!gp_idregex)
-	{
-		gp_idregex = pcre_compile("^ID_([^=]+)=(.*)$", 0, &p_error, &erroffset, NULL);
-		if(!gp_idregex)
-		{
-			fprintf(stderr, "error: gp_idregex compile failed - %s\n", p_error);
-			return 1;
-		}
-	}
-
-	numstrings = pcre_exec(gp_idregex, NULL, p_string, strlen(p_string), 0, 0, p_vector, 20);
-	if(numstrings < 0)
-		return 0;
-
-	pcre_get_substring(p_string, p_vector, numstrings, 1, &p_id);
-	pcre_get_substring(p_string, p_vector, numstrings, 2, &p_value);
-
-	if(!strcmp(p_id, "VIDEO_FORMAT"))
-	{
-		strncpy(g_sourcevideo.p_vcodec, p_value, sizeof(g_sourcevideo.p_vcodec) - 1);
-	}
-	if(!strcmp(p_id, "VIDEO_BITRATE"))
-	{
-		g_sourcevideo.vrate = atoi(p_value) / 1000;
-	}
-	if(!strcmp(p_id, "VIDEO_WIDTH"))
-	{
-		g_sourcevideo.width = atoi(p_value);
-	}
-	if(!strcmp(p_id, "VIDEO_HEIGHT"))
-	{
-		g_sourcevideo.height = atoi(p_value);
-		g_sourcevideo.aspect = (float)g_sourcevideo.width / (float)g_sourcevideo.height;
-	}
-	if(!strcmp(p_id, "VIDEO_FPS"))
-	{
-		g_sourcevideo.fps = atof(p_value);
-	}
-	if(!strcmp(p_id, "AUDIO_CODEC"))
-	{
-		strncpy(g_sourcevideo.p_acodec, p_value, sizeof(g_sourcevideo.p_acodec) - 1);
-	}
-	if(!strcmp(p_id, "AUDIO_BITRATE"))
-	{
-		g_sourcevideo.arate = atoi(p_value) / 1000;
-	}
-	if(!strcmp(p_id, "AUDIO_NCH"))
-	{
-		g_sourcevideo.achans = atoi(p_value);
-	}
-	if(!strcmp(p_id, "LENGTH"))
-	{
-		g_sourcevideo.length = atoi(p_value);
-		g_sourcevideo.hours   = g_sourcevideo.length / 3600;
-		g_sourcevideo.minutes = g_sourcevideo.length % 3600 / 60;
-		g_sourcevideo.seconds = g_sourcevideo.length % 60;
-	}
-
-	pcre_free_substring(p_id);
-	pcre_free_substring(p_value);
-
-	return 0;
-}
-
 int transcode(const char *p_cmd, int options)
 {
 	char p_cmdline[4096];
@@ -582,8 +509,13 @@ int encode(const char *p_infile, const char *p_outfile, int options, const char
 	/* multiplex */
 	if((options & SPANK_SECOND) || !(options & (SPANK_FIRST | SPANK_SECOND)))
 	{
-		snprintf(p_cmdline, sizeof(p_cmdline) - 1, "mplex -f 8 -o %s.mpg %s.m2v %s.ac3",
-			p_outfile, p_outfile, p_outfile);
+		printf("multiplexing..\n");
+		if((options & SPANK_SECOND))
+			snprintf(p_cmdline, sizeof(p_cmdline) - 1, "mplex -V -f 8 -o %s.mpg %s.m2v %s.ac3",
+				p_outfile, p_outfile, p_outfile);
+		else
+			snprintf(p_cmdline, sizeof(p_cmdline) - 1, "mplex -f 8 -o %s.mpg %s.m2v %s.ac3",
+				p_outfile, p_outfile, p_outfile);
 		if(multiplex(p_cmdline, options & SPANK_VERBOSE))
 			return 3;
 	}
@@ -595,6 +527,79 @@ int encode(const char *p_infile, const char *p_outfile, int options, const char
 	return 0;
 }
 
+int parsemplayer(const char *p_string)
+{
+	const char *p_error;
+	const char *p_id;
+	const char *p_value;
+	int p_vector[20];
+	int erroffset;
+	int numstrings;
+
+	if(!gp_idregex)
+	{
+		gp_idregex = pcre_compile("^ID_([^=]+)=(.*)$", 0, &p_error, &erroffset, NULL);
+		if(!gp_idregex)
+		{
+			fprintf(stderr, "error: gp_idregex compile failed - %s\n", p_error);
+			return 1;
+		}
+	}
+
+	numstrings = pcre_exec(gp_idregex, NULL, p_string, strlen(p_string), 0, 0, p_vector, 20);
+	if(numstrings < 0)
+		return 0;
+
+	pcre_get_substring(p_string, p_vector, numstrings, 1, &p_id);
+	pcre_get_substring(p_string, p_vector, numstrings, 2, &p_value);
+
+	if(!strcmp(p_id, "VIDEO_FORMAT"))
+	{
+		strncpy(g_sourcevideo.p_vcodec, p_value, sizeof(g_sourcevideo.p_vcodec) - 1);
+	}
+	if(!strcmp(p_id, "VIDEO_BITRATE"))
+	{
+		g_sourcevideo.vrate = atoi(p_value) / 1000;
+	}
+	if(!strcmp(p_id, "VIDEO_WIDTH"))
+	{
+		g_sourcevideo.width = atoi(p_value);
+	}
+	if(!strcmp(p_id, "VIDEO_HEIGHT"))
+	{
+		g_sourcevideo.height = atoi(p_value);
+		g_sourcevideo.aspect = (float)g_sourcevideo.width / (float)g_sourcevideo.height;
+	}
+	if(!strcmp(p_id, "VIDEO_FPS"))
+	{
+		g_sourcevideo.fps = atof(p_value);
+	}
+	if(!strcmp(p_id, "AUDIO_CODEC"))
+	{
+		strncpy(g_sourcevideo.p_acodec, p_value, sizeof(g_sourcevideo.p_acodec) - 1);
+	}
+	if(!strcmp(p_id, "AUDIO_BITRATE"))
+	{
+		g_sourcevideo.arate = atoi(p_value) / 1000;
+	}
+	if(!strcmp(p_id, "AUDIO_NCH"))
+	{
+		g_sourcevideo.achans = atoi(p_value);
+	}
+	if(!strcmp(p_id, "LENGTH"))
+	{
+		g_sourcevideo.length = atoi(p_value);
+		g_sourcevideo.hours   = g_sourcevideo.length / 3600;
+		g_sourcevideo.minutes = g_sourcevideo.length % 3600 / 60;
+		g_sourcevideo.seconds = g_sourcevideo.length % 60;
+	}
+
+	pcre_free_substring(p_id);
+	pcre_free_substring(p_value);
+
+	return 0;
+}
+
 int getvideoinfo(const char *p_file)
 {
 	char p_buffer[1024];
@@ -602,6 +607,9 @@ int getvideoinfo(const char *p_file)
 	pid_t pid;
 	int status;
 	int count;
+	int start;
+	int pos;
+	int copy;
 
 	/* open comminication pipe */
 	if(pipe(gp_inpipe) == -1)
@@ -625,10 +633,33 @@ int getvideoinfo(const char *p_file)
 			close(gp_inpipe[1]);
 			while(waitpid(pid, &status, WNOHANG))
 				;
-			while( (count = read(gp_inpipe[0], p_buffer, sizeof(p_buffer) - 1)) )
+			start = 0;
+			while( (count = read(gp_inpipe[0], &p_buffer[start], sizeof(p_buffer) - 1 - start)) )
 			{
-				p_buffer[count] = 0;
-				parsemplayer(p_buffer);
+				p_buffer[start + count] = 0;
+				for(start = 0, pos = 0; pos < sizeof(p_buffer) - 1; pos++)
+				{
+					if(p_buffer[pos] == '\n' || p_buffer[pos] == '\r')
+					{
+						p_buffer[pos] = 0;
+						parsemplayer(&p_buffer[start]);
+						start = pos + 1;
+					}
+					else if(p_buffer[pos] == 0)
+					{
+						if(pos > start)
+						{
+							for(copy = 0; copy < pos - start; copy++)
+								p_buffer[copy] = p_buffer[start + copy];
+							start = pos - start;
+						}
+						else
+						{
+							start = 0;
+						}
+						break;
+					}
+				}
 			}
 			close(gp_inpipe[0]);
 			break;
@@ -738,7 +769,7 @@ int main(int argc, char **argv)
 			case 'I':
 				options |= SPANK_NONICE;
 				break;
-			case 'l':
+			case 'L':
 				printf(gp_licence);
 				exit(0);
 				break;
@@ -770,11 +801,10 @@ int main(int argc, char **argv)
 	/* set audio bitrate / codec and scale */
 	strcpy(g_destvideo.p_acodec, "AC3");
 	if(!arate)
-	{
 		arate = g_sourcevideo.arate;
-	}
 	for(g_destvideo.arate = 64; g_destvideo.arate < arate; g_destvideo.arate += 32)
 		;
+	arate = g_destvideo.arate;
 
 	/* set audio channels */
 	if(channels)
@@ -807,10 +837,14 @@ int main(int argc, char **argv)
 
 	/* set video rate */
 	if(vrate)
+	{
 		g_destvideo.vrate = vrate;
+	}
 	else
+	{
 		g_destvideo.vrate = g_sourcevideo.vrate;
-	vrate = g_destvideo.vrate;
+		vrate = g_destvideo.vrate;
+	}
 
 	/* set aspect ratio */
 	if(aspect == 2)
@@ -855,9 +889,9 @@ int main(int argc, char **argv)
 
 	/* set length */
 	g_destvideo.length  = g_sourcevideo.length;
-	g_destvideo.hours   = g_sourcevideo.length / 3600;
-	g_destvideo.minutes = g_sourcevideo.length % 3600 / 60;
-	g_destvideo.seconds = g_sourcevideo.length % 60;
+	g_destvideo.hours   = g_sourcevideo.hours;
+	g_destvideo.minutes = g_sourcevideo.minutes;
+	g_destvideo.seconds = g_sourcevideo.seconds;
 
 	/* set fps */
 	if(vidmode == 'p' && g_sourcevideo.fps == 25)
